ziggy.util

Package ziggy :: Module util |
[hide private]
[frames] | no frames]

# Module util

source code

Functions | [hide private]
make_histogram_frame() | source code
make_counting_frame() | source code
make_search_frame(suppress_lines) | source code
make_identity_frame() | source code
sort_numeric(input_file, output_file, ascending=True, num_mappers=None, num_reducers=None) | source code
sort_ascii(input_file, output_file, ascending=True, num_mappers=None, num_reducers=None) | source code
search(input_directory, input_files, output_file, search_pattern, suppress_lines=True, num_mappers=None, num_reducers=None) | source code
histogram(input_file, output_file, num_mappers=None, num_reducers=None) | source code

Variables | [hide private]
| tmp_directory = ``'``/tmp``'``
| __package__ = ``'``ziggy``'``